%define build_test 0

# commandline overrides:
# rpm -ba|--rebuild --with 'xxx'
%{?_with_test: %{expand: %%global build_test 1}}
%{?_without_test: %{expand: %%global build_test 0}}

%define defaultmaxfiles 8192

Summary:	The Squid proxy caching server
Name:		squid
Version:	5.9
Release:	%mkrel 1
License:	GPLv2
Group:		System/Servers
URL:		http://www.squid-cache.org/
Source0:	http://www.squid-cache.org/Versions/v5/squid-%{version}.tar.xz
Source1:	http://www.squid-cache.org/Versions/v5/squid-%{version}.tar.xz.asc
Source4:	squid.logrotate
Source5:	squid.conf.authenticate
Source6:	smb.conf
Source7:	squid.conf.transparent
Source8:	rc.firewall
Source9:	ERR_CUSTOM_ACCESS_DENIED.English
Source10:	ERR_CUSTOM_ACCESS_DENIED.French
Source11: 	squid.sysconfig
Source13:	squid.pam
Source14:	squid.ifup
Source15:	squid.service
Source16:       cache_swap.sh

Patch1:		squid-config.diff
Patch2:		squid-user_group.diff
Patch11:	squid-shutdown_lifetime.diff
Patch13:	squid-errordir.diff
Patch19:	squid-3.4.9-configure-egrep.patch
	
# Change /var/run to /run
Patch302:	squid-4.7-var-run-to-run.patch


Requires(post): rpm-helper
Requires(preun): rpm-helper
Requires(pre): rpm-helper
BuildRequires:	bzip2
BuildRequires:	ed
BuildRequires:	libtool-devel
BuildRequires:	db-devel
BuildRequires:	pkgconfig(libsasl2)
BuildRequires:	openldap-devel
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pam-devel
BuildRequires:	pkgconfig
BuildRequires:	libtool
BuildRequires:	krb5-devel
BuildRequires:	pkgconfig(libecap)
BuildRequires:	pkgconfig(libcap)
BuildRequires:	pkgconfig(libsystemd)
BuildRequires:	samba-winbind
BuildRequires:  chrpath
%if %{build_test}
BuildRequires:	cppunit-devel
%endif
Provides:	webproxy

%description
Squid is a high-performance proxy caching server for web clients, supporting
FTP, gopher, and HTTP data objects over IPv4 or IPv6. Unlike traditional
caching software, Squid handles all requests in a single, non-blocking,
asynchronous process.

Squid keeps meta data and especially hot objects cached in RAM, caches DNS
lookups, supports non-blocking DNS lookups, and implements negative caching of
failed requests.  Squid supports SSL, extensive access controls, and full
request logging. By using the lightweight Internet Cache Protocol (ICP) and
HTTP Cache Protocol (HTCP) Squid caches can be arranged in a hierarchy or mesh
for additional bandwidth savings.

Install squid if you need a proxy caching server.

This package defaults to a maximum of %{defaultmaxfiles} filedescriptors. You
can change these values at build time by using for example:

--define 'maxfiles 4096'

The package was built to support a maximum of %{?!maxfiles:%{defaultmaxfiles}}%{?maxfiles:%{maxfiles}} filedescriptors.

You can build %{name} with some conditional build switches;

(ie. use with rpm --rebuild):
    --with[out]	test	Initiate the test suite

%package	cachemgr
Summary:	The Squid Cache Manager
Group:		System/Servers
Requires(pre): rpm-helper
Requires(pre):	apache >= 2.0.54
Requires(pre):	%{name} = %{version}
Requires:	apache >= 2.0.54
Requires:	%{name} = %{version}

%description	cachemgr
This package contains the Squid Cache Manager.

%prep
%setup -q
%patch1 -p1 -b .config
%patch2 -p0 -b .user_group
%patch11 -p0 -b .shutdown_lifetime
%patch13 -p1 -b .errordir
%patch19 -p1 -b .egrep
%patch302 -p1

find . -type d -perm 0700 -exec chmod 755 {} \;
find . -type f -perm 0555 -exec chmod 755 {} \;
find . -type f -perm 0444 -exec chmod 644 {} \;

for i in `find . -type d -name CVS`  `find . -type d -name .svn` `find . -type f -name .cvs\*` `find . -type f -name .#\*`; do
    if [ -e "$i" ]; then rm -rf $i; fi >&/dev/null
done

install -p -m 0644 %{SOURCE5} squid.conf.authenticate
install -p -m 0644 %{SOURCE6} smb.conf
install -p -m 0644 %{SOURCE7} squid.conf.transparent
install -p -m 0755 %{SOURCE8} rc.firewall

# fix conditional pam config file
install -p -m 0644 %{SOURCE13} squid.pam

perl -p -i -e "s|^SAMBAPREFIX.*|SAMBAPREFIX = /usr|" src/auth/basic/SMB/Makefile.*
grep -r "local/bin/perl" . |sed -e "s/:.*$//g" | xargs perl -p -i -e "s@local/bin/perl@bin/perl@g"

#Fix sysctl.h deprecation
perl -pi -e "s|<sys/sysctl.h>|<linux/sysctl.h>|g" src/eui/Eui48.cc

# fix paths
perl -pi -e "s|lib/squid|%{_lib}/squid|g" squid.conf.authenticate

%build
autoreconf -fi
%serverbuild

# NIS helper has been removed because of the following bug
# https://bugzilla.redhat.com/show_bug.cgi?id=1531540
%configure \
    --disable-strict-error-checking \
    --libexecdir=%{_libdir}/squid \
    --datadir=%{_datadir}/squid \
    --sysconfdir=%{_sysconfdir}/squid \
    --with-logdir='%{_localstatedir}/log/squid' \
    --disable-arch-native \
    --enable-shared=no \
    --enable-static=no \
    --enable-xmalloc-statistics \
    --enable-carp \
    --enable-async-io \
    --enable-storeio="aufs,diskd,ufs" \
    --enable-removal-policies="heap,lru" \
    --enable-icmp \
    --enable-delay-pools \
    --disable-esi \
    --enable-icap-client \
    --enable-ecap \
    --enable-useragent-log \
    --enable-referer-log \
    --enable-wccp \
    --enable-wccpv2 \
    --disable-kill-parent-hack \
    --enable-snmp \
    --enable-cachemgr-hostname="localhost" \
    --enable-arp-acl \
    --enable-htcp \
    --enable-ssl \
    --enable-ssl-crtd \
    --enable-forw-via-db \
    --enable-follow-x-forwarded-for \
    --enable-cache-digests \
    --disable-poll \
    --enable-epoll \
    --enable-linux-netfilter \
    --disable-ident-lookups \
    %ifnarch x86_64 aarch64
    --with-large-files \
    %endif
    --enable-default-hostsfile=/etc/hosts \
    --enable-auth \
    --enable-auth-basic="DB,fake,getpwnam,LDAP,NCSA,PAM,POP3,RADIUS,SASL,SMB,SMB_LM" \
    --enable-auth-ntlm="fake,SMB_LM" \
    --enable-auth-negotiate="kerberos,wrapper" \
    --enable-auth-digest="eDirectory,file,LDAP" \
    --enable-external-acl-helpers="eDirectory_userip,file_userip,kerberos_ldap_group,LDAP_group,session,unix_group,wbinfo_group" \
    --enable-storeid-rewrite-helpers="file" \
    --with-default-user=%{name} \
    --with-pthreads \
    --with-dl \
    --with-openssl=%{_prefix} \
    --with-large-files \
    --with-swapdir=%{_localstatedir}/spool/squid \
    --with-build-environment=default \
    --enable-mit=`/usr/bin/krb5-config --prefix` \
    --with-logdir=%{_logdir}/squid \
    --enable-http-violations \
    --enable-zph-qos \
    --enable-systemd \
    --with-pidfile=%{_rundir}/%{name}.pid \
    --sysconfdir=%{_sysconfdir}/squid \
    --with-filedescriptors=%{?!maxfiles:%{defaultmaxfiles}}%{?maxfiles}

# workaround to build squid v5
mkdir -p src/icmp/tests
mkdir -p tools/squidclient/tests
mkdir -p tools/tests
%make_build

%if %{build_test}
%check
make check
%endif

%install
%make_install

# remove chrpath
chrpath --delete %{buildroot}%{_libdir}/%{name}/ext_session_acl

# make some directories
install -d %{buildroot}%{_sysconfdir}/{logrotate.d,pam.d,sysconfig}
install -d %{buildroot}%{_sysconfdir}/sysconfig/network-scripts/ifup.d
install -d %{buildroot}%{_webconfdir}/webapps.d
install -d %{buildroot}%{_datadir}/squid/{errors,icons}
install -d %{buildroot}%{_datadir}/squid/errors/{English,French}
install -d %{buildroot}%{_mandir}/man8
install -d %{buildroot}%{_var}/www/cgi-bin
install -d %{buildroot}%{_logdir}/squid
install -d %{buildroot}%{_var}/spool/squid
install -d %{buildroot}%{_datadir}/squid/snmp/mibs

# fix error docs location	
rm -rf %{buildroot}%{_sysconfdir}/squid/errors
pushd errors
    for i in *; do
	if [ -d $i ]; then
	    install -d %{buildroot}%{_datadir}/squid/errors/$i
	    install -p -m0644 $i/* %{buildroot}%{_datadir}/squid/errors/$i
	fi
    done
popd
ln -fs %{_datadir}/squid/errors/templates %{buildroot}%{_sysconfdir}/squid/errors

# install config
install -p -m0644 %{SOURCE4} %{buildroot}%{_sysconfdir}/logrotate.d/squid
install -p -m0644 %{SOURCE11} %{buildroot}%{_sysconfdir}/sysconfig/squid
install -p -m0755 %{SOURCE14} %{buildroot}%{_sysconfdir}/sysconfig/network-scripts/ifup.d/squid
install -p -m0755 %{SOURCE15} -D %{buildroot}%{_unitdir}/%{name}.service
install -p -m0755 %{SOURCE16} -D %{buildroot}%{_libexecdir}/squid/cache_swap.sh

# fix docs
cp -a src/auth/basic/SASL/basic_sasl_auth.conf .

cp -a src/acl/external/file_userip/example.conf ip_user_external_acl.example.conf
cp -a src/acl/external/LDAP_group/ChangeLog ChangeLog.ldap_group_external_acl

head -19 src/auth/basic/NCSA/basic_ncsa_auth.cc > README.NCSA_basic_auth
head -56 src/auth/basic/PAM/basic_pam_auth.cc > README.PAM_basic_auth
head -21 src/auth/basic/getpwnam/basic_getpwnam_auth.cc > README.getpwnam_basic_auth
head -32 src/auth/digest/LDAP/digest_pw_auth.cc > README.ldap_digest_auth

install -p -m 0755 src/auth/basic/SMB/basic_smb_auth.sh %{buildroot}%{_libdir}/squid
install -p -m 0755 src/auth/basic/SASL/basic_sasl_auth %{buildroot}%{_libdir}/squid

for manpage in `find -name "*.8"`; do
    install -p -m 0644 $manpage %{buildroot}%{_mandir}/man8/
done

install -p -m 0644 %{SOURCE9} %{buildroot}%{_datadir}/squid/errors/English/ERR_CUSTOM_ACCESS_DENIED
install -p -m 0644 %{SOURCE10} %{buildroot}%{_datadir}/squid/errors/French/ERR_CUSTOM_ACCESS_DENIED

install -p -m 0644 squid.pam %{buildroot}%{_sysconfdir}/pam.d/squid

# move cachemgr.cgi to a more safe location
mv %{buildroot}%{_libdir}/squid/cachemgr.cgi %{buildroot}%{_var}/www/cgi-bin/

# provide a simple apache config
cat > %{buildroot}%{_webconfdir}/webapps.d/squid-cachemgr.conf << EOF
<Location /cgi-bin/cachemgr.cgi>
    Require local granted
    ErrorDocument 403 "Access denied per /etc/httpd/conf/webapps.d/squid-cachemgr.conf"
</Location>
EOF

# some cleaning
rm -f %{buildroot}%{_libdir}/squid/no_check.pl

# nuke zero length files
find %{buildroot}%{_datadir}/squid/errors/ -type f -size 0 -exec rm -f {} \;

# install /usr/lib/tmpfiles.d/squid.conf
mkdir -p %{buildroot}%{_tmpfilesdir}
cat > %{buildroot}%{_tmpfilesdir}/squid.conf <<EOF
# See tmpfiles.d(5) for details
d /run/squid 0755 squid squid - -	
EOF

# Move the MIB definition to the proper place (and name)
mkdir -p %{buildroot}/usr/share/snmp/mibs
mv %{buildroot}/usr/share/squid/mib.txt %{buildroot}/usr/share/snmp/mibs/SQUID-MIB.txt

# remove unpackaged files from the buildroot
rm -f %{buildroot}/squid.httpd.tmp


%pre
%_pre_useradd squid %{_var}/spool/squid /bin/false

for i in %{_logdir}/squid %{_var}/spool/squid ; do
        if [ -d $i ] ; then
                for adir in `find $i -maxdepth 0 \! -user squid`; do
                        chown -R squid:squid $adir
                done
        fi
done

%post
%_create_ssl_certificate squid

%_post_service squid
 case "$LANG" in
  az*)
     DIR=Azerbaijani
     ;;
  bg*)
     DIR=Bulgarian
     ;;
  ca*)
     DIR=Catalan
     ;;
  cs*)
     DIR=Czech
     ;;
  da*)
     DIR=Danish
     ;;
  nl*)
     DIR=Dutch
     ;;
  en*)
     DIR=English
     ;;
  ea*)
     DIR=Estonian
     ;;
  fi*)
     DIR=Finnish
     ;;
  fr*)
     DIR=French
     ;;
  de*)
     DIR=German
     ;;
  el*)
     DIR=Greek
     ;;
  he*)
     DIR=Hebrew
     ;;
  hu*)
     DIR=Hungarian
     ;;
  it*)
     DIR=Italian
     ;;
  ja*)
     DIR=Japanese
     ;;
  kr*)
     DIR=Korean
     ;;
  lt*)
     DIR=Lithuanian
     ;;
  pl*)
     DIR=Polish
     ;;
  pt*)
     DIR=Portuguese
     ;;
  ro*)
     DIR=Romanian
     ;;
  ru*)
     DIR=Russian-koi8-r
     ;;
  sr*)
     DIR=Serbian
     ;;
  sk*)
     DIR=Slovak
     ;;
  es*)
     DIR=Spanish
     ;;
  sv*)
     DIR=Swedish
     ;;
  zh*)
     DIR=Traditional_Chinese
     ;;
  tr*)
     DIR=Turkish
     ;;
  *)
     DIR=English
     ;;
 esac

%preun
%_preun_service squid

%pretrans -p <lua>
-- Define the path to the symlink being replaced below.
path = "%{_datadir}/squid/errors/es-mx"
st = posix.stat(path)
if st and st.type == "link" then
  os.remove(path)
end

%files
%doc C* R* Q* rc.firewall *.conf* doc/*.txt
%exclude %{_sysconfdir}/squid/cachemgr.conf
%exclude %{_sysconfdir}/squid/cachemgr.conf.default
%dir %{_sysconfdir}/squid	
%attr(755,root,root) %dir %{_libdir}/squid
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/squid/*.conf
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/squid/*.default
%exclude %{_sysconfdir}/squid/cachemgr.conf
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/pam.d/squid
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/sysconfig/squid
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/logrotate.d/squid
%attr(0755,root,squid) %config(noreplace) %{_sysconfdir}/sysconfig/network-scripts/ifup.d/squid
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/squid/*.css
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/squid/*.documented
%{_sysconfdir}/squid/errors
%{_datadir}/squid/errors
%{_datadir}/squid/icons
%{_libdir}/squid/*
%{_libexecdir}/squid/
%{_unitdir}/%{name}.service

%{_sbindir}/*
%{_bindir}/purge
%{_bindir}/squidclient
%attr(0644,root,root) %{_mandir}/man1/*
%attr(0644,root,root) %{_mandir}/man8/basic*
%attr(0644,root,root) %{_mandir}/man8/digest_file_auth.8*
%attr(0644,root,root) %{_mandir}/man8/ext_*
%attr(0644,root,root) %{_mandir}/man8/helper-mux.8*
%attr(0644,root,root) %{_mandir}/man8/log_db_daemon.8*
%attr(0644,root,root) %{_mandir}/man8/n*
%attr(0644,root,root) %{_mandir}/man8/s*
%attr(0644,root,root) %{_mandir}/man8/u*
%attr(0755,squid,squid) %dir %{_logdir}/squid
%attr(0755,squid,squid) %dir %{_var}/spool/squid
%{_datadir}/snmp/mibs/SQUID-MIB.txt
%{_tmpfilesdir}/squid.conf

%files cachemgr
%attr(0644,root,root) %config(noreplace) %{_webconfdir}/webapps.d/squid-cachemgr.conf
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/squid/cachemgr.conf
%attr(0755,root,squid) %{_var}/www/cgi-bin/cachemgr.cgi
%attr(0644,root,root) %{_mandir}/man8/cachemgr.cgi.8.*


%changelog
* Mon May 01 2023 kekepower <kekepower> 5.9-1.mga9
+ Revision: 1955575
- Update to version 5.9
+ luigiwalser <luigiwalser>
- 5.8
- rediff patch 1

* Tue Jan 03 2023 umeabot <umeabot> 5.7-2.mga9
+ Revision: 1929555
- Rebuild to use libldap-2.5 instead of 2.4

* Tue Sep 06 2022 luigiwalser <luigiwalser> 5.7-1.mga9
+ Revision: 1884493
- 5.7
- remove upstreamed patches 206 and 207

* Mon Jun 06 2022 kekepower <kekepower> 5.6-1.mga9
+ Revision: 1861389
- Update to version 5.6

* Thu Apr 14 2022 luigiwalser <luigiwalser> 5.5-1.mga9
+ Revision: 1849311
- 5.5

* Wed Mar 30 2022 umeabot <umeabot> 5.4.1-2.mga9
+ Revision: 1833787
- Mageia 9 Mass Rebuild

* Sun Feb 13 2022 luigiwalser <luigiwalser> 5.4.1-1.mga9
+ Revision: 1774085
- 5.4.1

* Mon Feb 07 2022 luigiwalser <luigiwalser> 5.4-1.mga9
+ Revision: 1772550
- 5.4

* Tue Dec 07 2021 luigiwalser <luigiwalser> 5.3-1.mga9
+ Revision: 1761049
- 5.3

* Tue Oct 05 2021 joequant <joequant> 5.2-1.mga9
+ Revision: 1749658
- add chrpath
- update to 5.2
- update to openssl
+ luigiwalser <luigiwalser>
- 5.2
+ wally <wally>
- disable strict error checking while building
- rebuild for openssl 3.0.0

* Fri Aug 06 2021 luigiwalser <luigiwalser> 5.1-1.mga9
+ Revision: 1739925
- 5.1
- fix call to non-existening init script in ifup script
- update example configs to use ufdbguard instead of squidguard (mga#29155)

* Fri Jul 23 2021 luigiwalser <luigiwalser> 5.0.7-1.mga9
+ Revision: 1737557
- 5.0.7
+ wally <wally>
- drop %%postun scriptlet doing nothing

* Sat Jun 19 2021 wally <wally> 5.0.6-3.mga9
+ Revision: 1731205
- fix %%preun and don't remove logs after uninstall
- add %%pretrans lua scriptlet to replace es-mx symlink with a directory

* Fri Jun 18 2021 wally <wally> 5.0.6-2.mga9
+ Revision: 1731136
- fix systemd service file

* Wed Jun 16 2021 joequant <joequant> 5.0.6-1.mga9
+ Revision: 1730899
- update to 5.0.6

* Sat May 15 2021 luigiwalser <luigiwalser> 4.15-1.mga9
+ Revision: 1723281
- 4.15

* Mon Feb 08 2021 luigiwalser <luigiwalser> 4.14-1.mga9
+ Revision: 1675056
- 4.14

* Wed Nov 25 2020 tv <tv> 4.13-5.mga8
+ Revision: 1649261
- Removed NIS helper in order to fix build with glibc-2.32 (rhbz#1531540)

* Wed Nov 04 2020 joequant <joequant> 4.13-4.mga8
+ Revision: 1642687
- use installed configure

* Thu Sep 03 2020 luigiwalser <luigiwalser> 4.13-3.mga8
+ Revision: 1621200
- remove squid.init and unused squid.service from rundir patch
- remove SysV init script
- explicit requires on systemd-unit not needed
- use _unitdir macro

* Thu Sep 03 2020 bcornec <bcornec> 4.13-2.mga8
+ Revision: 1621184
- Adds systemd support to squid

* Sun Aug 23 2020 luigiwalser <luigiwalser> 4.13-1.mga8
+ Revision: 1618161
- 4.13
+ bcornec <bcornec>
- Fix mga#26884 by updating to upstream squid 4.12

* Mon Jul 13 2020 joequant <joequant> 4.12-2.mga8
+ Revision: 1605781
- add --foreground to cache creation

* Tue Jun 09 2020 luigiwalser <luigiwalser> 4.12-1.mga8
+ Revision: 1591519
- 4.12

* Tue Apr 21 2020 luigiwalser <luigiwalser> 4.11-1.mga8
+ Revision: 1570167
- 4.11
- rediff patch 302

* Wed Feb 19 2020 umeabot <umeabot> 4.10-2.mga8
+ Revision: 1543930
- Mageia 8 Mass Rebuild

* Thu Jan 23 2020 luigiwalser <luigiwalser> 4.10-1.mga8
+ Revision: 1482433
- 4.10
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Nov 12 2019 zezinho <zezinho> 4.9-1.mga8
+ Revision: 1459416
- new version 4.9
- move cachemgr manpage to proper subpackage

* Thu Oct 31 2019 daviddavid <daviddavid> 4.8-2.mga8
+ Revision: 1457131
- fix /etc/{logrotate.d,pam.d,sysconfig} (mga#25637)

* Sat Aug 24 2019 bcornec <bcornec> 4.8-1.mga8
+ Revision: 1431764
- New patch to fix sysctl.h deprecation under sys
- Add an upstream patch to fix gcc-8 build
- Now uses an upstream patched version of squid that should fix previous compilation problems
- Update to upstream 4.8 and fixes CVE-2019-13345, CVE-2019-1252[579]

* Wed May 15 2019 kekepower <kekepower> 4.7-2.mga7
+ Revision: 1397828
- Use /run instead of /var/run to please systemd

* Sun May 12 2019 luigiwalser <luigiwalser> 4.7-1.mga7
+ Revision: 1397332
- 4.7

* Wed Feb 20 2019 luigiwalser <luigiwalser> 4.6-1.mga7
+ Revision: 1369006
- 4.6

* Tue Jan 01 2019 luigiwalser <luigiwalser> 4.5-1.mga7
+ Revision: 1348185
- 4.5

* Sun Nov 11 2018 kekepower <kekepower> 4.4-2.mga7
+ Revision: 1329571
- Use pkgconfig() where possible
- Update macros throughout the spec

* Tue Oct 30 2018 bcornec <bcornec> 4.4-1.mga7
+ Revision: 1326778
- update to upstream squid which fixes mga#23780

* Fri Oct 12 2018 bcornec <bcornec> 4.3-1.mga7
+ Revision: 1319743
- Update to upstream squid 4.3

* Wed Oct 10 2018 bcornec <bcornec> 3.5.28-1.mga7
+ Revision: 1319170
- Update to upstream squid 3.5.28 (make bm happy by adding more no-error as warnings are treated as errors)
- ed was a missing dep for squid build
+ pterjan <pterjan>
- Mageia 7 Mass Rebuild

* Mon Jan 22 2018 luigiwalser <luigiwalser> 3.5.27-5.mga7
+ Revision: 1196079
- add upstream patches to fix SQUID-2018:1 and SQUID-2018:2

* Fri Nov 10 2017 luigiwalser <luigiwalser> 3.5.27-4.mga7
+ Revision: 1176816
- disable gcc7 build error
- rebuild for openssl 1.0

* Sun Aug 27 2017 guillomovitch <guillomovitch> 3.5.27-2.mga7
+ Revision: 1148286
- change build dependencies to keep building against openssl 1.0
+ luigiwalser <luigiwalser>
- 3.5.27

* Fri Jun 02 2017 luigiwalser <luigiwalser> 3.5.26-1.mga6
+ Revision: 1105826
- 3.5.26

* Mon Apr 03 2017 luigiwalser <luigiwalser> 3.5.25-1.mga6
+ Revision: 1095782
- 3.5.25

* Sun Jan 29 2017 luigiwalser <luigiwalser> 3.5.24-1.mga6
+ Revision: 1083904
- 3.5.24

* Sat Dec 17 2016 luigiwalser <luigiwalser> 3.5.23-1.mga6
+ Revision: 1075813
- 3.5.23

* Sat Dec 10 2016 ngompa <ngompa> 3.5.22-2.mga6
+ Revision: 1074117
- Remove unneeded %%pretrans

* Mon Oct 10 2016 luigiwalser <luigiwalser> 3.5.22-1.mga6
+ Revision: 1059988
- 3.5.22

* Fri Sep 09 2016 luigiwalser <luigiwalser> 3.5.21-1.mga6
+ Revision: 1050935
- 3.5.21

* Tue Jul 05 2016 luigiwalser <luigiwalser> 3.5.20-1.mga6
+ Revision: 1039031
- 3.5.20

* Mon May 23 2016 bcornec <bcornec> 3.5.19-2.mga6
+ Revision: 1017906
- bum mkrel for rebuild
- Fix #18269 fir squid with a buggy startup script

* Mon May 09 2016 luigiwalser <luigiwalser> 3.5.19-1.mga6
+ Revision: 1011266
- 3.5.19

* Fri May 06 2016 luigiwalser <luigiwalser> 3.5.18-1.mga6
+ Revision: 1010071
- 3.5.18 (fixes CVE-2016-455[3-6])

* Thu Apr 21 2016 luigiwalser <luigiwalser> 3.5.17-1.mga6
+ Revision: 1004059
- 3.5.17 (fixes CVE-2016-4051)

* Mon Apr 04 2016 luigiwalser <luigiwalser> 3.5.16-1.mga6
+ Revision: 998431
- 3.5.16 (fixes CVE-2016-3947 and CVE-2016-3948)
- remove upstream patches

* Mon Mar 14 2016 luigiwalser <luigiwalser> 3.5.15-4.mga6
+ Revision: 990731
- fix scriplet to fix upgrade from mga5

* Mon Mar 14 2016 luigiwalser <luigiwalser> 3.5.15-3.mga6
+ Revision: 990658
- add upstream patches to fix crashes

* Thu Mar 03 2016 umeabot <umeabot> 3.5.15-2.mga6
+ Revision: 984135
- Rebuild for openssl

* Wed Feb 24 2016 luigiwalser <luigiwalser> 3.5.15-1.mga6
+ Revision: 978495
- 3.5.15

* Mon Feb 15 2016 luigiwalser <luigiwalser> 3.5.14-1.mga6
+ Revision: 961604
- 3.5.14

* Thu Jan 07 2016 luigiwalser <luigiwalser> 3.5.13-1.mga6
+ Revision: 920367
- 3.5.13

* Thu Dec 17 2015 bcornec <bcornec> 3.5.12-2.mga6
+ Revision: 911179
- Fix #17298 by adding support of ssl_crtd

* Mon Nov 30 2015 luigiwalser <luigiwalser> 3.5.12-1.mga6
+ Revision: 907238
- 3.5.12

* Mon Nov 02 2015 luigiwalser <luigiwalser> 3.5.11-1.mga6
+ Revision: 897463
- 3.5.11

* Fri Oct 02 2015 luigiwalser <luigiwalser> 3.5.10-1.mga6
+ Revision: 885685
- 3.5.10

* Fri Sep 18 2015 luigiwalser <luigiwalser> 3.5.9-1.mga6
+ Revision: 880335
- 3.5.9

* Wed Sep 02 2015 luigiwalser <luigiwalser> 3.5.8-1.mga6
+ Revision: 872162
- 3.5.8

* Tue Aug 25 2015 cjw <cjw> 3.5.7-2.mga6
+ Revision: 869297
- rebuild with gcc 5

* Mon Aug 03 2015 luigiwalser <luigiwalser> 3.5.7-1.mga6
+ Revision: 860924
- remove upstreamed patch 9
- 3.5.7

* Sat Jul 04 2015 luigiwalser <luigiwalser> 3.5.6-1.mga6
+ Revision: 849846
- 3.5.6

* Wed Jul 01 2015 luigiwalser <luigiwalser> 3.5.5-2.mga6
+ Revision: 849392
- fix upgrade from mga5

* Mon Jun 22 2015 dlucio <dlucio> 3.5.5-1.mga6
+ Revision: 838694
- 3.5.5
- P16 & P18 rediffed
- filelist updated

* Fri May 01 2015 luigiwalser <luigiwalser> 3.4.13-1.mga5
+ Revision: 820966
- 3.4.13 (fixes CVE-2015-3455)

* Wed Feb 18 2015 luigiwalser <luigiwalser> 3.4.12-1.mga5
+ Revision: 815768
- 3.4.12

* Tue Jan 13 2015 luigiwalser <luigiwalser> 3.4.11-1.mga5
+ Revision: 810388
- 3.4.11

* Wed Dec 10 2014 luigiwalser <luigiwalser> 3.4.10-1.mga5
+ Revision: 802598
- 3.4.10
- do not strip fPIC from flags

* Sat Nov 22 2014 cjw <cjw> 3.4.9-3.mga5
+ Revision: 798269
- configure with --disable-arch-native so the package also runs on hardware is not exactly the same as the build machine (fixes #14639)
- patch19: fix a configure error caused by EGREP being used before it was defined
- configure with --enable-shared=no
- drop useless -fPIC from compilation flags

* Fri Nov 21 2014 luigiwalser <luigiwalser> 3.4.9-2.mga5
+ Revision: 798206
- rebuild to hopefully fix illegal instruction error (mga#14639)

* Tue Nov 04 2014 luigiwalser <luigiwalser> 3.4.9-1.mga5
+ Revision: 795514
- 3.4.9
- remove upstreamed patch

* Wed Oct 15 2014 umeabot <umeabot> 3.4.8-2.mga5
+ Revision: 740388
- Second Mageia 5 Mass Rebuild

* Tue Sep 23 2014 luigiwalser <luigiwalser> 3.4.8-1.mga5
+ Revision: 721637
- 3.4.8

* Thu Aug 28 2014 luigiwalser <luigiwalser> 3.4.7-1.mga5
+ Revision: 669018
- 3.4.7

* Thu Jun 26 2014 dlucio <dlucio> 3.4.6-1.mga5
+ Revision: 640113
- Winbind requiered to build helper
- 3.4.6

* Mon May 05 2014 luigiwalser <luigiwalser> 3.4.5-1.mga5
+ Revision: 620303
- 3.4.5

* Sat Apr 26 2014 luigiwalser <luigiwalser> 3.4.4.2-1.mga5
+ Revision: 618324
- 3.4.4.2

* Mon Mar 10 2014 luigiwalser <luigiwalser> 3.4.4-1.mga5
+ Revision: 601741
- 3.4.4

* Tue Mar 04 2014 luigiwalser <luigiwalser> 3.4.3-2.mga5
+ Revision: 599531
- use makeinstall_std macro (mga#12914)
- fix patch 13 to cope with the change

* Fri Feb 21 2014 luigiwalser <luigiwalser> 3.4.3-1.mga5
+ Revision: 595381
- 3.4.3
- remove upstreamed pod2man patch
- eDirectory digest auth helper cannot be built right now

* Thu Dec 05 2013 luigiwalser <luigiwalser> 3.3.11-1.mga4
+ Revision: 555331
- 3.3.11

* Tue Nov 05 2013 luigiwalser <luigiwalser> 3.3.10-1.mga4
+ Revision: 549752
- 3.3.10

* Fri Sep 13 2013 luigiwalser <luigiwalser> 3.3.9-1.mga4
+ Revision: 478615
- 3.3.9

* Tue Aug 27 2013 luigiwalser <luigiwalser> 3.3.8-3.mga4
+ Revision: 472092
- rebuild for cyrus-sasl

* Thu Aug 22 2013 luigiwalser <luigiwalser> 3.3.8-2.mga4
+ Revision: 469820
- work around pod2man bug (mga#10663)

* Mon Jul 15 2013 luigiwalser <luigiwalser> 3.3.8-1.mga4
+ Revision: 454897
- 3.3.8

* Thu Jul 11 2013 luigiwalser <luigiwalser> 3.3.7-1.mga4
+ Revision: 453018
- 3.3.7

* Wed Jul 10 2013 luigiwalser <luigiwalser> 3.3.5-3.mga4
+ Revision: 452432
- do not require ksh for kerberos_ldap_group acl helper cert_tool script

* Sun Jun 30 2013 luigiwalser <luigiwalser> 3.3.5-2.mga4
+ Revision: 448558
- temporarily disable DB auth helper and log daemon as pod2man is broken
- fix selection of auth and acl helpers (mga#10516)

* Fri May 24 2013 dlucio <dlucio> 3.3.5-1.mga4
+ Revision: 426211
- 3.3.5
- P8 & P17 merged
- P19 no needed
- file list update

* Mon Apr 29 2013 dlucio <dlucio> 3.2.10-1.mga3
+ Revision: 411554
- 3.2.10
- P19 added

* Thu Mar 14 2013 luigiwalser <luigiwalser> 3.2.9-1.mga3
+ Revision: 403193
- 3.2.9

* Tue Mar 05 2013 luigiwalser <luigiwalser> 3.2.8-1.mga3
+ Revision: 401415
- 3.2.8

* Thu Feb 14 2013 dlucio <dlucio> 3.2.7-2.mga3
+ Revision: 398300
- P18 to fix purge default paths

* Fri Feb 01 2013 luigiwalser <luigiwalser> 3.2.7-1.mga3
+ Revision: 393931
- 3.2.7

* Thu Jan 10 2013 luigiwalser <luigiwalser> 3.2.6-1.mga3
+ Revision: 344483
- 3.2.6

* Sun Jan 06 2013 cjw <cjw> 3.2.5-2.mga3
+ Revision: 339716
- patch17: fix build with automake 1.13
+ oden <oden>
- fix the apache config

* Tue Dec 18 2012 dlucio <dlucio> 3.2.5-1.mga3
+ Revision: 332665
- 3.2.5

* Fri Dec 07 2012 dlucio <dlucio> 3.2.4-1.mga3
+ Revision: 327751
- 3.2.4

* Sat Oct 27 2012 dlucio <dlucio> 3.2.3-1.mga3
+ Revision: 310607
- 3.2.3

* Fri Oct 19 2012 luigiwalser <luigiwalser> 3.2.2-1.mga3
+ Revision: 308301
- 3.2.2

* Sat Sep 08 2012 luigiwalser <luigiwalser> 3.2.1-1.mga3
+ Revision: 289665
- fix doc files list
- 3.2.1
- sync with mdv, which includes:
  - re-diffed patches
  - upstreamed patches removed
  - updated configure options
  - updated files lists

* Tue Jul 31 2012 fwang <fwang> 3.1.20-3.mga3
+ Revision: 276374
- rebuild for db-5.3

* Fri Jul 20 2012 dlucio <dlucio> 3.1.20-2.mga3
+ Revision: 272760
- rebuild for new db51

* Sun Jul 15 2012 dlucio <dlucio> 3.1.20-1.mga3
+ Revision: 271084
- 3.1.20
- new patches to fix little memory leaks with ecap

* Tue May 08 2012 pterjan <pterjan> 3.1.19-4.mga2
+ Revision: 234914
- Fix initscript's LSB header

* Thu Mar 22 2012 dlucio <dlucio> 3.1.19-3.mga2
+ Revision: 225611
+ rebuild (emptylog)

* Wed Mar 21 2012 dlucio <dlucio> 3.1.19-2.mga2
+ Revision: 225313
- P18 & P19 added, now we have COAP support

* Fri Feb 10 2012 dlucio <dlucio> 3.1.19-1.mga2
+ Revision: 206873
- 3.1.19

* Sat Dec 10 2011 dlucio <dlucio> 3.1.18-1.mga2
+ Revision: 180451
- 3.1.18
  p18 to fix compilling

* Sun Oct 16 2011 dlucio <dlucio> 3.1.16-1.mga2
+ Revision: 155477
- 3.1.16

* Fri Sep 30 2011 dlucio <dlucio> 3.1.15-3.mga2
+ Revision: 150455
- cosmetic message fixed when creating cache structure

* Thu Sep 15 2011 dmorgan <dmorgan> 3.1.15-2.mga2
+ Revision: 144111
- Fix apache requires
+ dlucio <dlucio>
- Spec fixes, squid init fixes
- 3.1.5
- rebuild for new LDAP
- rebuild for new LDAP
- SPEC clean ups
- Trying to make a single RPM compatible with both distros, anyway it helps me to maintain both
- Trying to make a single RPM compatible with both distros, anyway it helps me to maintain both
- 3.1.14
- 3.1.12.2

* Tue Jun 14 2011 dlucio <dlucio> 3.1.12.2-1.mga2
+ Revision: 106204
- 3.1.12.2

* Sun May 15 2011 pterjan <pterjan> 3.1.12-2.mga1
+ Revision: 99033
- Rebuild for fixed find-requires

* Sun May 01 2011 misc <misc> 3.1.12-1.mga1
+ Revision: 94056
- clean file list from comment
- upgrade to 3.1.12, bugfixes only release ( http://www.mail-archive.com/squid-users@squid-cache.org/msg78434.html )
- remove unapplied patches

* Wed Apr 13 2011 tv <tv> 3.1.11-1.mga1
+ Revision: 84624
- use real version in RPM tags

* Mon Mar 07 2011 ennael <ennael> 3.1-26.mga1
+ Revision: 66297
- fix patches in spec file
- clean spec file
+ dlucio <dlucio>
- 3.1.11
- 3.1.11
- imported package squid

